=================================
skadi: Financial Machine Learning
=================================
.. image:: https://img.shields.io/badge/License-Apache%202.0-green.svg
    :target: https://github.com/ailares-quant/skadi/blob/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/pypi/v/skadi.svg


.. image:: https://travis-ci.com/ailares-quant/skadi.svg?token=Q8VAKqwMEe56Bd2dytyt&branch=master
    :target: https://travis-ci.com/ailares-quant/skadi
    :alt: CI Status


.. image:: https://readthedocs.com/projects/ailares-skadi/badge/?version=latest&token=8c809426dcdf8ee674fe784539ad6b093981d942f2af93a165133391ac9b402b
    :target: https://ailares-skadi.readthedocs-hosted.com/en/latest/?badge=latest
    :alt: Documentation Status

Skadi is `Ailares, Inc. <https://www.ailares.com/>`_ in-house quantitative research infrastructure.

**Ailares, Inc.** develops quantitative investment strategies to bring investors risk-adjusted return.

* Free software: Apache Software License 2.0
* Documentation: https://ailares-skadi.readthedocs-hosted.com/en/latest/

© 2019 Ailares, Inc. All rights reserved.
